#ifndef DIST_H
#define DIST_H

double dist(double x1, double y1, double x2, double y2);

double dist2(double x1, double y1, double x2, double y2);

double norm(double *x, int dim);

#endif
